@@ -35,8 +35,7 @@ class AwsDal(Dal, ff.LoggerAware):
 
     def store(self, df: pd.DataFrame, table: domain.Table):
         self._ensure_db_created(table)
-
-        df = df[list(map(lambda c: c.name, table.columns))]
+        df = df[list(map(lambda c: c.name, table.columns)) + table.partitions]
 
         if 'created_on' in table.type_dict:
             df['created_on'].fillna(datetime.utcnow(), inplace=True)
@@ -49,7 +48,7 @@ class AwsDal(Dal, ff.LoggerAware):
             'dataset': True,
             'database': table.database.name,
             'table': table.name,
-            'partition_cols': table.partitions,
+            'partition_cols': table.partitions.copy(),
             'regular_partitions': True,
             'compression': 'snappy',
             'dtype': table.type_dict,
